Installation
============
The most recent release can be installed from
`PyPI <https://pypi.org/project/oncvpsp_tools>`_ with:

.. code-block:: shell

    pip install oncvpsp_tools

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    pip install git+https://github.com/pseudopotential-tools/oncvpsp-tools.git

To install in development mode, use the following:

.. code-block:: shell

    git clone git+https://github.com/pseudopotential-tools/oncvpsp-tools.git
    cd oncvpsp-tools
    pip install -e .
